@@ -19,7 +19,7 @@
 #ifndef _BABL_VERSION_H
 #define _BABL_VERSION_H
 
-#ifndef BABL_INSIDE_BABL_H
+#if !defined(BABL_INSIDE_BABL_H) && !defined(BABL_IS_BEING_COMPILED)
 #error "babl-version.h must not be included directly, include babl.h instead."
 #endif
 
@@ -34,7 +34,7 @@
 
 #define BABL_MAJOR_VERSION 0
 #define BABL_MINOR_VERSION 1
-#define BABL_MICRO_VERSION 2
+#define BABL_MICRO_VERSION 4
 
 /** Get the version information on the babl library */
 void   babl_get_version (int *major,
